# -*- coding: utf-8 -*-
from zope.deferredimport import deprecated


deprecated(
    "Import from Products.CMFPlone.patterns.view instead",
    PatternSettings="Products.CMFPlone.patterns.view.PatternSettingsView",
)



# -*- coding: utf-8 -*-
from zope.interface import Interface
from zope.schema import Bool


class INextPreviousProvider(Interface):
    """A folderish component capable of describing the next and previous
    item relative to a particular id.
    """

    enabled = Bool(title=u"True if next/previous behaviour is enabled")

    def getNextItem(obj):
        """Returns information about next item in the container relative to
        the given object.

        This is a dict with the following keys:

            - id, the id of the object
            - url, the url of the object
            - title, the title of the object
            - description, a description of the object
            - portal_type, the object's portal type
        """

    def getPreviousItem(obj):
        """Returns the previous item in the container relative to the given
        object
        """



# -*- coding: utf-8 -*-
from zope.deferredimport import deprecated


# remove in Plone 6
deprecated(
    "Import from Products.CMFPlone instead",
    DefaultPage="Products.CMFPlone.browser.defaultpage:DefaultPage",
    isDefaultPage="Products.CMFPlone.defaultpage:is_default_page",
    getDefaultPage="Products.CMFPlone.defaultpage:get_default_page",
)



from zope.component import adapter
from plone.registry.interfaces import IRecordModifiedEvent
from Products.CMFPlone.interfaces import ISiteSchema
from plone.formwidget.namedfile.converter import b64decode_file
import mimetypes
from zope.component import getUtility
from plone.registry.interfaces import IRegistry
from plone.registry.recordsproxy import RecordsProxy


@adapter(ISiteSchema, IRecordModifiedEvent)
def updateMimetype(settings: RecordsProxy, event: IRecordModifiedEvent=None):

    if event.record.fieldName != 'site_favicon' or not event.record.value:
        return

    filename = b64decode_file(event.newValue)[0]
    mimetype = mimetypes.guess_type(filename)[0] if filename else None
    if mimetype in ('image/x-icon', None):
        # Override incorrect MIME type registered in both PIL and the
        # Products.MimetypesRegistry product.
        mimetype = 'image/vnd.microsoft.icon'
    settings.__registry__['plone.site_favicon_mimetype'] = mimetype



# -*- coding: utf-8 -*-
from plone.app.layout.viewlets.tests.base import ViewletsTestCase
from plone.app.layout.testing import FUNCTIONAL_TESTING
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.interfaces.syndication import ISiteSyndicationSettings
from zope.component import getUtility
from plone.namedfile.file import NamedBlobFile
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.interfaces import ISecuritySchema, ISiteSchema
from plone.app.layout.viewlets.tests.base import ViewletsTestCase
from plone.app.layout.links.viewlets import FaviconViewlet
from plone.formwidget.namedfile.converter import b64encode_file


class TestFaviconViewletView(ViewletsTestCase, FaviconViewlet):
    layer = FUNCTIONAL_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        self.request = ''
        self.site_url = ''

    def test_FaviconViewlet_get_mimetype_svg(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(ISiteSchema, prefix="plone")
        filename = 'test.svg'
        file_data = 'Hello World'.encode()
        encoded_data = b64encode_file(filename=filename, data=file_data)
        settings.site_favicon = encoded_data
        mimetype = settings.site_favicon_mimetype
        self.assertEqual(mimetype, 'image/svg+xml')

    def test_FaviconViewlet_get_mimetype_jpg(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(ISiteSchema, prefix="plone")
        filename = 'test.jpg'
        file_data = 'Hello World'.encode()
        encoded_data = b64encode_file(filename=filename, data=file_data)
        settings.site_favicon = encoded_data
        mimetype = settings.site_favicon_mimetype
        self.assertEqual(mimetype, 'image/jpeg')

    def test_FaviconViewlet_get_mimetype_png(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(ISiteSchema, prefix="plone")
        filename = 'test.png'
        file_data = 'Hello World'.encode()
        encoded_data = b64encode_file(filename=filename, data=file_data)
        settings.site_favicon = encoded_data
        mimetype = settings.site_favicon_mimetype
        self.assertEqual(mimetype, 'image/png')

    def test_FaviconViewlet_get_mimetype_ico(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(ISiteSchema, prefix="plone")
        filename = 'test.ico'
        file_data = 'Hello World'.encode()
        encoded_data = b64encode_file(filename=filename, data=file_data)
        settings.site_favicon = encoded_data
        mimetype = settings.site_favicon_mimetype
        self.assertEqual(mimetype, 'image/vnd.microsoft.icon')

    def test_FaviconViewlet_get_mimetype_none(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(ISiteSchema, prefix="plone")
        settings.site_favicon = None
        mimetype = settings.site_favicon_mimetype
        self.assertEqual(mimetype, 'image/vnd.microsoft.icon')
